@@ -1,17 +1,22 @@
 use core::ops::RangeBounds;
 
-use crate::{Rng, SeedError};
+use crate::{Rng, SeedSource};
 
 #[thread_local]
-pub(crate) static RNG: Rng =
-    Rng::from_seed_with_192bit([0x50B88B1357314D73, 0x8E4193B54C35742C, 0x47C6FF4737815FC5]);
+pub(crate) static RNG: Rng = Rng::fixed_tls();
 
 #[cfg_attr(docsrs, doc(cfg(feature = "tls")))]
-/// Seeds the thread local instance from the best available entropy pool.
-pub fn seed() -> Result<(), SeedError> {
+/// Seeds the thread local instance from the best available randomness source.
+pub fn seed() {
     RNG.seed()
 }
 
+#[cfg_attr(docsrs, doc(cfg(feature = "tls")))]
+/// Shows which source was used to acquire the seed for the thread local instance.
+pub fn seed_source() -> SeedSource {
+    RNG.seed_source()
+}
+
 #[cfg_attr(docsrs, doc(cfg(feature = "tls")))]
 /// Seeds the thread local instance with the given 64-bit seed.
 pub fn seed_with_64bit(seed: u64) {
@@ -36,7 +41,7 @@ pub fn seed_with_192bit(seed: [u64; 3]) {
 #[cfg_attr(docsrs, doc(cfg(feature = "tls")))]
 /// Mixes the state, which should improve the quality of the random numbers.
 ///
-/// Should be called when having (re-)seeded the generator with a fixed value of low entropy.
+/// Should be called when having (re-)seeded the generator with a fixed value of low randomness.
 pub fn mix() {
     RNG.mix()
 }
@@ -112,14 +117,14 @@ pub fn isize() -> isize {
 }
 
 #[cfg_attr(docsrs, doc(cfg(feature = "tls")))]
-/// Generates a random f32 value.
+/// Generates a random f32 value in range (0..1).
 #[inline(always)]
 pub fn f32() -> f32 {
     RNG.f32()
 }
 
 #[cfg_attr(docsrs, doc(cfg(feature = "tls")))]
-/// Generates a random f64 value.
+/// Generates a random f64 value in range (0..1).
 #[inline(always)]
 pub fn f64() -> f64 {
     RNG.f64()
@@ -202,54 +207,63 @@ pub fn range_u8<T: RangeBounds<u8>>(range: T) -> u8 {
 
 #[cfg_attr(docsrs, doc(cfg(feature = "tls")))]
 /// Generates a random u16 value in the given range.
+#[inline(always)]
 pub fn range_u16<T: RangeBounds<u16>>(range: T) -> u16 {
     RNG.range_u16(range)
 }
 
 #[cfg_attr(docsrs, doc(cfg(feature = "tls")))]
 /// Generates a random u32 value in the given range.
+#[inline(always)]
 pub fn range_u32<T: RangeBounds<u32>>(range: T) -> u32 {
     RNG.range_u32(range)
 }
 
 #[cfg_attr(docsrs, doc(cfg(feature = "tls")))]
 /// Generates a random u64 value in the given range.
+#[inline(always)]
 pub fn range_u64<T: RangeBounds<u64>>(range: T) -> u64 {
     RNG.range_u64(range)
 }
 
 #[cfg_attr(docsrs, doc(cfg(feature = "tls")))]
 /// Generates a random usize value in the given range.
+#[inline(always)]
 pub fn range_usize<T: RangeBounds<usize>>(range: T) -> usize {
     RNG.range_usize(range)
 }
 
 #[cfg_attr(docsrs, doc(cfg(feature = "tls")))]
 /// Generates a random i8 value in the given range.
+#[inline(always)]
 pub fn range_i8<T: RangeBounds<i8>>(range: T) -> i8 {
     RNG.range_i8(range)
 }
 
 #[cfg_attr(docsrs, doc(cfg(feature = "tls")))]
 /// Generates a random i16 value in the given range.
+#[inline(always)]
 pub fn range_i16<T: RangeBounds<i16>>(range: T) -> i16 {
     RNG.range_i16(range)
 }
 
 #[cfg_attr(docsrs, doc(cfg(feature = "tls")))]
 /// Generates a random i32 value in the given range.
+#[inline(always)]
 pub fn range_i32<T: RangeBounds<i32>>(range: T) -> i32 {
     RNG.range_i32(range)
 }
 
 #[cfg_attr(docsrs, doc(cfg(feature = "tls")))]
 /// Generates a random i64 value in the given range.
+#[inline(always)]
 pub fn range_i64<T: RangeBounds<i64>>(range: T) -> i64 {
     RNG.range_i64(range)
 }
 
 #[cfg_attr(docsrs, doc(cfg(feature = "tls")))]
 /// Generates a random isize value in the given range.
+#[inline(always)]
 pub fn range_isize<T: RangeBounds<isize>>(range: T) -> isize {
     RNG.range_isize(range)
 }
